@@ -1,4 +1,4 @@
-// ライセンス: 最新のGPL
+// ライセンス: GPL2
 
 //#define _DEBUG
 #include "jddebug.h"
@@ -69,11 +69,14 @@ int del_img_day;
 int max_img_size;
 
 bool show_oldarticle;
+int newthread_hour;
 
 int tree_scroll_size;
 bool open_one_category;
 bool always_write_ok;
 bool save_postlog;
+bool hide_writing_dialog;
+
 int margin_popup;
 int mouse_radius;
 int history_size;
@@ -83,6 +86,7 @@ double adjust_underline_pos;
 double adjust_line_space;
 
 bool draw_underline;
+bool strict_char_width;
 
 int tab_min_str;
 
@@ -95,6 +99,9 @@ std::list< std::string > list_abone_name;
 std::list< std::string > list_abone_word;
 std::list< std::string > list_abone_regex;
 
+bool abone_transparent;
+bool abone_chain;
+
 
 //
 // 初期設定
@@ -231,6 +238,9 @@ const bool CONFIG::init_config()
     // boardビューで古いスレも表示
     show_oldarticle = cf.get_option( "show_oldarticle", false );
 
+    // スレ一覧で指定した値(時間)よりも後に立てられたスレを新着とみなす
+    newthread_hour = cf.get_option( "newthread_hour", 24 );
+
 
     /////////////////////////
     // UI 周りの設定
@@ -247,6 +257,9 @@ const bool CONFIG::init_config()
     // 書き込みログを保存
     save_postlog = cf.get_option( "save_postlog", false );
 
+    // 書き込み中のダイアログを表示しない
+    hide_writing_dialog = cf.get_option( "hide_writing_dialog", false );
+
     // ポップアップとカーソルの間のマージン
     margin_popup = cf.get_option( "margin_popup", 30 );
 
@@ -266,6 +279,9 @@ const bool CONFIG::init_config()
     // リンク下線を表示
     draw_underline = cf.get_option( "draw_underline", true );
 
+    // スレビューで文字幅の近似を厳密にする
+    strict_char_width = cf.get_option( "strict_char_width", false );
+
     // タブに表示する文字列の最小値
     tab_min_str = cf.get_option( "tab_min_str", 4 );
 
@@ -296,6 +312,10 @@ const bool CONFIG::init_config()
     str_tmp = cf.get_option( "aboneregex", "" );
     if( ! str_tmp.empty() ) list_abone_regex = MISC::strtolist( str_tmp );
 
+    // デフォルトで透明、連鎖あぼーんをするか
+    abone_transparent = cf.get_option( "abone_transparent", false );
+    abone_chain = cf.get_option( "abone_chain", false );
+
     return ! cf.empty();
 }
 
@@ -386,11 +406,13 @@ void CONFIG::save_conf()
     cf.update( "color_popup_B", color_back_popup[ 2 ] );
 
     cf.update( "show_oldarticle", show_oldarticle );
+    cf.update( "newthread_hour", newthread_hour );
 
     cf.update( "tree_scroll_size", tree_scroll_size );
     cf.update( "open_one_category", open_one_category );
     cf.update( "always_write_ok", always_write_ok );
     cf.update( "save_postlog", save_postlog );
+    cf.update( "hide_writing_dialog", hide_writing_dialog );
     cf.update( "margin_popup", margin_popup );
     cf.update( "mouse_radius", mouse_radius );
     cf.update( "history_size", history_size );
@@ -400,6 +422,7 @@ void CONFIG::save_conf()
     cf.update( "adjust_line_space", adjust_line_space );
 
     cf.update( "draw_underline", draw_underline );
+    cf.update( "strict_char_width", strict_char_width );
 
     cf.update( "tab_min_str", tab_min_str );
 
@@ -421,6 +444,9 @@ void CONFIG::save_conf()
     cf.update( "aboneword", str_abone_word );
     cf.update( "aboneregex", str_abone_regex );
 
+    cf.update( "abone_transparent", abone_transparent );
+    cf.update( "abone_chain", abone_chain );
+
     cf.save();
 }
 
@@ -521,12 +547,16 @@ const int CONFIG::get_max_img_size(){ return max_img_size; }
 const bool CONFIG::get_show_oldarticle(){ return show_oldarticle; }
 void CONFIG::set_show_oldarticle( bool showarticle ){ show_oldarticle = showarticle; }
 
+const int CONFIG::get_newthread_hour(){ return newthread_hour; }
+
 const int CONFIG::get_tree_scroll_size(){ return tree_scroll_size; }
 const bool CONFIG::get_open_one_category(){ return open_one_category; }
 const bool CONFIG::get_always_write_ok() { return always_write_ok; }
 void CONFIG::set_always_write_ok( bool write_ok ){ always_write_ok = write_ok; }
 const bool CONFIG::get_save_postlog(){ return save_postlog; }
 void CONFIG::set_save_postlog( bool save ){ save_postlog = save; }
+const bool CONFIG::get_hide_writing_dialog(){ return hide_writing_dialog; }
+
 const int CONFIG::get_margin_popup(){ return margin_popup; }
 const int CONFIG::get_mouse_radius(){ return mouse_radius; }
 const int CONFIG::get_history_size(){ return history_size; }
@@ -542,6 +572,7 @@ const double CONFIG::get_adjust_underline_pos(){ return adjust_underline_pos; }
 const double CONFIG::get_adjust_line_space(){ return adjust_line_space; }
 
 const bool CONFIG::get_draw_underline(){ return draw_underline; }
+const bool CONFIG::get_strict_char_width(){ return strict_char_width; }
 
 const int CONFIG::get_tab_min_str(){ return tab_min_str; }
 
@@ -593,3 +624,7 @@ void CONFIG::set_list_abone_regex( std::list< std::string >& regex )
     list_abone_regex = MISC::remove_nullline_from_list( list_abone_regex );
 }
 
+const bool CONFIG::get_abone_transparent(){ return abone_transparent; }
+void CONFIG::set_abone_transparent( bool set ){ abone_transparent = set; }
+const bool CONFIG::get_abone_chain(){ return abone_chain; }
+void CONFIG::set_abone_chain( bool set ){ abone_chain = set; }
