@@ -1,4 +1,4 @@
-// ライセンス: 最新のGPL
+// ライセンス: GPL2
 //
 // グローバル設定
 //
@@ -142,6 +142,9 @@ namespace CONFIG
     const bool get_show_oldarticle();
     void set_show_oldarticle( bool showarticle );
 
+    // スレ一覧で指定した値(時間)よりも後に立てられたスレを新着とみなす
+    const int get_newthread_hour();
+
     // ツリービューのスクロール量(行数)
     const int get_tree_scroll_size();
 
@@ -156,6 +159,9 @@ namespace CONFIG
     const bool get_save_postlog();
     void set_save_postlog( bool save );
 
+    // 書き込み中のダイアログを表示しない
+    const bool get_hide_writing_dialog();
+
     // ポップアップとカーソルの間のマージン
     const int get_margin_popup();
 
@@ -175,6 +181,9 @@ namespace CONFIG
     // スレ表示でリンクの下に下線を引く
     const bool get_draw_underline();
 
+    // スレビューで文字幅の近似を厳密にする
+    const bool get_strict_char_width();
+
     // タブに表示する文字列の最小値
     const int get_tab_min_str();
 
@@ -196,6 +205,13 @@ namespace CONFIG
     void set_list_abone_name( std::list< std::string >& name );
     void set_list_abone_word( std::list< std::string >& word );
     void set_list_abone_regex( std::list< std::string >& regex );
+
+    // デフォルトで透明、連鎖あぼーんをするか
+    const bool get_abone_transparent();
+    void set_abone_transparent( bool set );
+
+    const bool get_abone_chain();
+    void set_abone_chain( bool set );
 }
 
 
