@@ -1,4 +1,4 @@
-// ライセンス: 最新のGPL
+// ライセンス: GPL2
 
 //#define _DEBUG
 #include "jddebug.h"
@@ -161,8 +161,8 @@ void ImageAdmin::clock_in()
     }
 
     // アクティブなviewにだけクロックを送る
-    // admin がフォーカスされていないなら何もしない
-    if( has_focus() ){
+    // admin が画面に表示されていないなら何もしない
+    if( SESSION::is_img_shown() ){
         SKELETON::View* view = get_current_view();
         if( view ) view->clock_in();
     }
@@ -205,6 +205,13 @@ void ImageAdmin::command_local( const COMMAND_ARGS& command )
     // 切り替え
     if( command.command == "switch_image" ) switch_img( command.url );
 
+    // 画像強制表示
+    if( command.command == "show_image" ){
+        clock_in();
+        clock_in();
+        clock_in();
+    }
+
     // すべて保存
     else if( command.command  == "save_all" ) save_all();
 
@@ -433,6 +440,8 @@ void ImageAdmin::close_view( const std::string& url )
     SKELETON::View* icon = get_icon( url );
     SKELETON::View* view = get_view( url );
 
+    if( ! icon && ! view ) return;
+
     // 現在表示中のviewを閉じた場合は次か前の画像に切り替える
     if( view && view == get_current_view() ){
 
@@ -586,8 +595,6 @@ void ImageAdmin::switch_img( const std::string& url )
         }
     }
 
-    // 全アイコンのフォーカスを一旦はずす
-    // 後でフォーカスしておくこと
     focus_out_all();
 
     // アイコン切り替え
@@ -616,6 +623,8 @@ void ImageAdmin::switch_img( const std::string& url )
             adjust->set_value( pos_to );
         }
     }
+
+    if( has_focus() ) focus_current_view();
 }
 
 
